@@ -15,7 +15,7 @@ from urllib.parse import parse_qsl, quote, urlencode, urljoin, urlsplit
 import httpx
 
 
-__version__ = "0.26.0"
+__version__ = "0.27.2"
 __project__ = "aioauth-client"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -168,6 +168,14 @@ class Client(object, metaclass=ClientRegistry):
         """Parse user's information from given provider data."""
         yield 'id', None
 
+    def get_authorize_url(self, **params) -> str:
+        """Get an authorization URL."""
+        return self.authorize_url
+
+    async def get_access_token(self, *args, **kwargs) -> t.Tuple[str, t.Any]:
+        """Abstract base method."""
+        raise NotImplementedError
+
 
 class OAuth1Client(Client):
     """Implement OAuth1."""
@@ -231,20 +239,20 @@ class OAuth1Client(Client):
 
         return self._request(method, url, params=oparams, headers=headers, **options)
 
-    async def get_request_token(self, **params) -> t.Tuple[str, str, t.Any]:
+    async def get_request_token(self, **params) -> t.Tuple[str, t.Any]:
         """Get a request_token and request_token_secret from OAuth1 provider."""
         params = dict(self.params, **params)
         data = await self.request(
             'GET', self.request_token_url, raise_for_status=True, params=params)
         if not isinstance(data, dict):
-            return '', '', data
+            return '', data
 
-        self.oauth_token = data.get('oauth_token')
+        self.oauth_token = data.get('oauth_token') or ''
         self.oauth_token_secret = data.get('oauth_token_secret')
-        return self.oauth_token, self.oauth_token_secret, data  # type: ignore
+        return self.oauth_token, data
 
-    async def get_access_token(
-            self, oauth_verifier, request_token=None, headers=None, **params):
+    async def get_access_token(self, oauth_verifier, request_token=None,  # type: ignore
+                               headers=None, **params) -> t.Tuple[str, t.Any]:
         """Get access_token from OAuth1 provider.
 
         :returns: (access_token, access_token_secret, provider_data)
@@ -262,10 +270,15 @@ class OAuth1Client(Client):
             'POST', self.access_token_url, raise_for_status=True, headers=headers,
             params={'oauth_verifier': oauth_verifier, 'oauth_token': request_token})
 
-        self.oauth_token = data.get('oauth_token')
+        if isinstance(data, str):
+            raise OAuthException(
+                'Failed to obtain OAuth 1.0 access token. '
+                f"Invalid data: {data}")
+
+        self.oauth_token = data.get('oauth_token') or ''
         self.oauth_token_secret = data.get('oauth_token_secret')
 
-        return self.oauth_token, self.oauth_token_secret, data
+        return self.oauth_token, data
 
 
 class OAuth2Client(Client):
@@ -307,7 +320,7 @@ class OAuth2Client(Client):
 
         return self._request(method, url, headers=headers, params=params, **options)
 
-    async def get_access_token(self, code: str, redirect_uri: str = None,
+    async def get_access_token(self, code: str, redirect_uri: str = None,  # type: ignore
                                headers: t.Dict = None, **payload) -> t.Tuple[str, t.Any]:
         """Get an access_token from OAuth provider.
 
